@@ -9,11 +9,12 @@ from conans.client.cmd.export_linter import conan_linter
 from conans.client.file_copier import FileCopier
 from conans.client.loader_parse import load_conanfile_class
 from conans.client.output import ScopedOutput
+from conans.client.source import get_scm_data
 from conans.errors import ConanException
 from conans.model.conan_file import create_exports, create_exports_sources
 from conans.model.manifest import FileTreeManifest
 from conans.model.ref import ConanFileReference
-from conans.model.scm import SCM, SCMData
+from conans.model.scm import SCM
 from conans.paths import CONAN_MANIFEST, CONANFILE
 from conans.util.files import save, rmdir, is_dirty, set_dirty, mkdir
 from conans.util.log import logger
@@ -104,13 +105,10 @@ def _capture_export_scm_data(conanfile, src_path, destination_folder, output, pa
     if os.path.exists(scm_src_file):
         os.unlink(scm_src_file)
 
-    try:
-        scm_data = SCMData(conanfile)
-    except ConanException:
+    scm_data = get_scm_data(conanfile)
+
+    if not scm_data or not (scm_data.capture_origin or scm_data.capture_revision):
         return
-    else:
-        if not (scm_data.capture_origin or scm_data.capture_revision):
-            return
 
     scm = SCM(scm_data, src_path)
 
