@@ -1,11 +1,8 @@
 import os
-from collections import Counter
 
 from conans.client import packager
-from conans.client.graph.build_requires import BuildRequires
 from conans.client.client_cache import ClientCache
 from conans.client.cmd.export import _execute_export
-from conans.client.graph.graph_builder import DepsGraphBuilder
 from conans.client.generators import write_generators
 from conans.client.generators.text import TXTGenerator
 from conans.client.importer import run_imports, run_deploy
@@ -14,8 +11,6 @@ from conans.client.loader import ConanFileLoader
 from conans.client.manifest_manager import ManifestManager
 from conans.client.output import ScopedOutput, Color
 from conans.client.profile_loader import read_conaninfo_profile
-from conans.client.proxy import ConanProxy
-from conans.client.graph.range_resolver import RangeResolver
 from conans.client.source import config_source_local, complete_recipe_sources
 from conans.client.tools import cross_building, get_cross_building_settings
 from conans.client.userio import UserIO
@@ -25,10 +20,10 @@ from conans.model.ref import ConanFileReference, PackageReference
 from conans.paths import CONANFILE, CONANINFO, CONANFILE_TXT, BUILD_INFO
 from conans.util.files import save, rmdir, normalize, mkdir, load
 from conans.util.log import logger
-from conans.client.loader_parse import load_conanfile_class
+from conans.client.graph.graph_manager import GraphManager
 from conans.client.graph.build_mode import BuildMode
-from conans.client.cmd.download import download_binaries
 from conans.client.graph.printer import print_graph
+from conans.client.graph.graph import BINARY_BUILD
 
 
 class ConanManager(object):
@@ -89,23 +84,17 @@ class ConanManager(object):
             self._settings_preprocessor.preprocess(cache_settings)
         return ConanFileLoader(self._runner, cache_settings, profile)
 
-    def get_proxy(self, remote_name=None):
-        remote_proxy = ConanProxy(self._client_cache, self._user_io, self._remote_manager,
-                                  remote_name=remote_name, recorder=self._recorder, registry=self._registry)
-        return remote_proxy
-
     def export_pkg(self, reference, source_folder, build_folder, package_folder, install_folder, profile, force):
 
         conan_file_path = self._client_cache.conanfile(reference)
         if not os.path.exists(conan_file_path):
             raise ConanException("Package recipe '%s' does not exist" % str(reference))
 
-        remote_proxy = self.get_proxy()
-
         loader = self.get_loader(profile)
         conanfile = loader.load_virtual([reference], scope_options=True)
-        graph_builder = self._get_graph_builder(loader, remote_proxy)
-        deps_graph = graph_builder.load_graph(conanfile, check_updates=False, update=False)
+        graph_builder = self._get_graph_builder(loader, self._recorder)
+        deps_graph = graph_builder.load_graph(conanfile, check_updates=False, update=False,
+                                              build_mode=None)
 
         # this is a bit tricky, but works. The root (virtual), has only 1 neighbor,
         # which is the exported pkg
@@ -137,47 +126,6 @@ class ConanManager(object):
             packager.create_package(conanfile, pkg_id, source_folder, build_folder,
                                     dest_package_folder, install_folder, package_output, local=True)
 
-    def download(self, reference, package_ids, remote_name, recipe):
-        """ Download conanfile and specified packages to local repository
-        @param reference: ConanFileReference
-        @param package_ids: Package ids or empty for download all
-        @param remote: install only from that remote
-        @param only_recipe: download only the recipe
-        """
-        assert(isinstance(reference, ConanFileReference))
-        output = ScopedOutput(str(reference), self._user_io.out)
-        remote = self._registry.remote(remote_name) if remote_name else self._registry.default_remote
-        package = self._remote_manager.search_recipes(remote, reference, None)
-        if not package:  # Search the reference first, and raise if it doesn't exist
-            raise ConanException("'%s' not found in remote" % str(reference))
-
-        # First of all download package recipe
-        self._remote_manager.get_recipe(reference, remote)
-        self._registry.set_ref(reference, remote)
-
-        if recipe:
-            return
-
-        # Download the sources too, don't be lazy
-        conan_file_path = self._client_cache.conanfile(reference)
-        conanfile = load_conanfile_class(conan_file_path)
-        complete_recipe_sources(self._remote_manager, self._client_cache, self._registry,
-                                conanfile, reference)
-
-        if package_ids:
-            download_binaries(reference, package_ids, self._client_cache, self._remote_manager,
-                              remote, output, self._recorder)
-        else:
-            output.info("Getting the complete package list "
-                        "from '%s'..." % str(reference))
-            packages_props = self._remote_manager.search_packages(remote, reference, None)
-            if not packages_props:
-                output = ScopedOutput(str(reference), self._user_io.out)
-                output.warn("No remote binary packages found in remote")
-            else:
-                download_binaries(reference, list(packages_props.keys()), self._client_cache,
-                                  self._remote_manager, remote, output, self._recorder)
-
     @staticmethod
     def _inject_require(conanfile, inject_require):
         """ test_package functionality requires injecting the tested package as requirement
@@ -191,35 +139,40 @@ class ConanManager(object):
         conanfile._user = inject_require.user
         conanfile._channel = inject_require.channel
 
-    def _get_graph_builder(self, loader, remote_proxy):
-        resolver = RangeResolver(self._user_io.out, self._client_cache, remote_proxy)
-        graph_builder = DepsGraphBuilder(remote_proxy, self._user_io.out, loader, resolver)
+    def _get_graph_builder(self, loader, action_recorder):
+        graph_builder = GraphManager(self._user_io.out, loader,
+                                     self._client_cache, self._registry, self._remote_manager,
+                                     action_recorder, workspace=None)
         return graph_builder
 
-    def _get_deps_graph(self, reference, profile, remote_proxy, check_updates, update):
+    def _get_deps_graph(self, reference, profile, check_updates, update, build_mode,
+                        remote_name):
         loader = self.get_loader(profile)
         conanfile = self._load_install_conanfile(loader, reference)
-        graph_builder = self._get_graph_builder(loader, remote_proxy)
-        deps_graph = graph_builder.load_graph(conanfile, check_updates, update)
-        return deps_graph, graph_builder, conanfile
+        graph_builder = self._get_graph_builder(loader, self._recorder)
+        build_mode = BuildMode(build_mode, self._user_io.out)
+        deps_graph = graph_builder.load_graph(conanfile, check_updates, update,
+                                              build_mode=build_mode, remote_name=remote_name,
+                                              profile_build_requires=profile.build_requires)
+        return deps_graph, conanfile
 
     def info_build_order(self, reference, profile, build_order, remote_name, check_updates):
-        remote_proxy = self.get_proxy(remote_name=remote_name)
-        deps_graph, _, _ = self._get_deps_graph(reference, profile, remote_proxy, update=False,
-                                                check_updates=check_updates)
+        deps_graph, _ = self._get_deps_graph(reference, profile, update=False,
+                                             check_updates=check_updates, build_mode=["missing"],
+                                             remote_name=remote_name)
         result = deps_graph.build_order(build_order)
         return result
 
-    def info_nodes_to_build(self, reference, profile, build_modes, remote_name, check_updates):
-        remote_proxy = self.get_proxy(remote_name=remote_name)
-        deps_graph, _, conanfile = self._get_deps_graph(reference, profile, remote_proxy, update=False,
-                                                        check_updates=check_updates)
-        build_mode = BuildMode(build_modes, self._user_io.out)
-        installer = ConanInstaller(self._client_cache, self._user_io.out, remote_proxy, build_mode,
-                                   None, recorder=self._recorder)
-        nodes = installer.nodes_to_build(deps_graph)
-        counter = Counter(ref.conan.name for ref, _ in nodes)
-        ret = [ref if counter[ref.conan.name] > 1 else str(ref.conan) for ref, _ in nodes]
+    def info_nodes_to_build(self, reference, profile, build_mode, remote_name, check_updates):
+        deps_graph, conanfile = self._get_deps_graph(reference, profile, update=False,
+                                                     check_updates=check_updates, build_mode=build_mode,
+                                                     remote_name=remote_name)
+        ret = []
+        for level in deps_graph.by_levels():
+            for node in level:
+                if node.binary == BINARY_BUILD:
+                    if node.conan_ref not in ret:
+                        ret.append(node.conan_ref)
         return ret, self._get_project_reference(reference, conanfile)
 
     def _get_project_reference(self, reference, conanfile):
@@ -230,42 +183,37 @@ class ConanManager(object):
 
         return project_reference
 
-    def info_get_graph(self, reference, profile, remote_name=None, check_updates=False):
+    def info_get_graph(self, reference, profile, remote_name=None, check_updates=False, build_mode=None):
         """ Fetch and build all dependencies for the given reference
         @param reference: ConanFileReference or path to user space conanfile
         @param remote: install only from that remote
         """
-        remote_proxy = self.get_proxy(remote_name=remote_name)
-        deps_graph, graph_builder, conanfile = self._get_deps_graph(reference, profile, remote_proxy,
-                                                                    update=False, check_updates=check_updates)
+        deps_graph, conanfile = self._get_deps_graph(reference, profile,
+                                                     update=False, check_updates=check_updates,
+                                                     build_mode=build_mode, remote_name=remote_name)
 
-        if check_updates:
-            graph_updates_info = graph_builder.get_graph_updates_info(deps_graph)
-        else:
-            graph_updates_info = {}
-
-        return deps_graph, graph_updates_info, self._get_project_reference(reference, conanfile)
+        return deps_graph, self._get_project_reference(reference, conanfile)
 
     def install_workspace(self, profile, workspace, remote_name, build_modes, update):
         loader = self.get_loader(profile)
         references = [ConanFileReference(v, "root", "project", "develop") for v in workspace.root]
         conanfile = loader.load_virtual(references)
-        remote_proxy = self.get_proxy(remote_name=remote_name)
-        graph_builder = self._get_graph_builder(loader, remote_proxy)
-        graph_builder._workspace = workspace
-        deps_graph = graph_builder.load_graph(conanfile, False, update)
+
+        graph_builder = GraphManager(self._user_io.out, loader,
+                                     self._client_cache, self._registry, self._remote_manager,
+                                     self._recorder, workspace=workspace)
+        build_mode = BuildMode(build_modes, self._user_io.out)
+        deps_graph = graph_builder.load_graph(conanfile, False, update, build_mode, remote_name,
+                                              profile.build_requires)
 
         output = ScopedOutput(str("Workspace"), self._user_io.out)
         output.highlight("Installing...")
         print_graph(deps_graph, self._user_io.out)
 
-        build_mode = BuildMode(build_modes, self._user_io.out)
-        build_requires = BuildRequires(loader, graph_builder, self._registry)
-        installer = ConanInstaller(self._client_cache, output, remote_proxy, build_mode,
-                                   build_requires, recorder=self._recorder)
-        installer._workspace = workspace
+        installer = ConanInstaller(self._client_cache, output, self._remote_manager,
+                                   self._registry, recorder=self._recorder, workspace=workspace)
+        installer.install(deps_graph, keep_build=False)
 
-        installer.install(deps_graph, profile.build_requires, keep_build=False, update=update)
         build_mode.report_matches()
         workspace.generate()
 
@@ -294,8 +242,6 @@ class ConanManager(object):
             generators = set(generators) if generators else set()
             generators.add("txt")  # Add txt generator by default
 
-        remote_proxy = self.get_proxy(remote_name=remote_name)
-
         loader = self.get_loader(profile)
         if not install_reference:
             if isinstance(reference, ConanFileReference):  # is a create
@@ -306,8 +252,10 @@ class ConanManager(object):
         if inject_require:
             self._inject_require(conanfile, inject_require)
 
-        graph_builder = self._get_graph_builder(loader, remote_proxy)
-        deps_graph = graph_builder.load_graph(conanfile, False, update)
+        graph_builder = self._get_graph_builder(loader, self._recorder)
+        build_mode = BuildMode(build_modes, self._user_io.out)
+        deps_graph = graph_builder.load_graph(conanfile, False, update, build_mode, remote_name,
+                                              profile.build_requires)
 
         if not isinstance(reference, ConanFileReference):
             output = ScopedOutput(("%s (test package)" % str(inject_require)) if inject_require else "PROJECT",
@@ -317,6 +265,7 @@ class ConanManager(object):
             output = ScopedOutput(str(reference), self._user_io.out)
             output.highlight("Installing package")
         print_graph(deps_graph, self._user_io.out)
+        build_mode.report_matches()
 
         try:
             if cross_building(loader._settings):
@@ -326,17 +275,9 @@ class ConanManager(object):
         except ConanException:  # Setting os doesn't exist
             pass
 
-        build_mode = BuildMode(build_modes, self._user_io.out)
-        build_requires = BuildRequires(loader, graph_builder, self._registry)
-        installer = ConanInstaller(self._client_cache, output, remote_proxy, build_mode,
-                                   build_requires, recorder=self._recorder)
-
-        # Apply build_requires to consumer conanfile
-        if not isinstance(reference, ConanFileReference):
-            build_requires.install("", conanfile, installer, profile.build_requires, output, update)
-
-        installer.install(deps_graph, profile.build_requires, keep_build, update=update)
-        build_mode.report_matches()
+        installer = ConanInstaller(self._client_cache, output, self._remote_manager,
+                                   self._registry, recorder=self._recorder, workspace=None)
+        installer.install(deps_graph, keep_build)
 
         if manifest_folder:
             manifest_manager = ManifestManager(manifest_folder, user_io=self._user_io,
